@@ -151,7 +151,9 @@ class DefaultBucketTests(BaseTestCase):
         self._server.start()
         self._session = requests.Session()
         self._client = _get_storage_client(self._session)
-        self._client.get_bucket("example.appspot.com")
+        bucket = self._client.get_bucket("example.appspot.com")
+        self.assertEqual(bucket.name, "example.appspot.com")
+        self.assertEqual(bucket.storage_class, "STANDARD")
 
 
 class ObjectsTests(ServerBaseCase):
@@ -746,6 +748,30 @@ class ObjectsTests(ServerBaseCase):
         with self.assertRaises(NotFound):
             self._client.get_bucket("batchbucket2")
 
+    def test_resumable_upload_small_chunk_size(self):
+        content = b"a" * 10000000
+        bucket = self._client.create_bucket("testbucket")
+
+        blob = bucket.blob("resumable-test", chunk_size=256 * 1024)
+        blob.upload_from_string(content)
+
+        blob = bucket.get_blob("resumable-test")
+        fetched_content = blob.download_as_bytes()
+        self.assertEqual(len(fetched_content), len(content))
+        self.assertEqual(fetched_content, content)
+
+    def test_resumable_upload_large_file(self):
+        content = b"abcde12345" * 20000000
+        bucket = self._client.create_bucket("testbucket")
+
+        blob = bucket.blob("resumable-test")
+        blob.upload_from_string(content)
+
+        blob = bucket.get_blob("resumable-test")
+        fetched_content = blob.download_as_bytes()
+        self.assertEqual(len(fetched_content), len(content))
+        self.assertEqual(fetched_content, content)
+
 
 class HttpEndpointsTest(ServerBaseCase):
     """Tests for the HTTP endpoints defined by server.HANDLERS."""
@@ -800,3 +826,34 @@ class HttpEndpointsTest(ServerBaseCase):
         response = requests.get(url)
         self.assertEqual(response.status_code, 200)
         self.assertEqual(response.content, content.encode("utf-8"))
+
+    def test_wipe(self):
+        """Objects should wipe the data"""
+        storage_path = os.path.join(STORAGE_BASE, STORAGE_DIR)
+        content = "Here is some content"
+        bucket = self._client.create_bucket("anotherbucket1")
+        blob = bucket.blob("something.txt")
+        blob.upload_from_string(content)
+
+        url = self._url("/wipe")
+        response = requests.get(url)
+        self.assertEqual(response.status_code, 200)
+        self.assertTrue(len(os.listdir(storage_path)) == 0)
+
+    def test_wipe_keep_buckets(self):
+        """Objects should wipe the data but keep the root buckets"""
+        blob_path = "something.txt"
+        bucket_name = "anewone"
+        content = "Here is some content"
+        bucket = self._client.create_bucket(bucket_name)
+        blob = bucket.blob(blob_path)
+        blob.upload_from_string(content)
+
+        url = self._url("/wipe?keep-buckets=true")
+        response = requests.get(url)
+        self.assertEqual(response.status_code, 200)
+
+        fetched_bucket = self._client.get_bucket(bucket_name)
+        self.assertEqual(fetched_bucket.name, bucket.name)
+        with self.assertRaises(NotFound):
+            fetched_bucket.blob(blob_path).download_as_text()
